@@ -40,7 +40,7 @@ size_t get_chunk_size (const size_t nfrom);
 
 namespace categorical {
 
-size_t num_edge_types (const std::vector <size_t> &edge_type);
+size_t get_num_edge_types (const std::vector <size_t> &edge_type);
 
 } // end namespace categorical
 
@@ -68,6 +68,12 @@ Rcpp::NumericMatrix rcpp_get_sp_dists_par (const Rcpp::DataFrame graph,
         const std::string& heap_type,
         const bool is_spatial);
 
+Rcpp::NumericVector rcpp_get_sp_dists_nearest (const Rcpp::DataFrame graph,
+        const Rcpp::DataFrame vert_map_in,
+        Rcpp::IntegerVector fromi,
+        Rcpp::IntegerVector toi_in,
+        const std::string& heap_type);
+
 Rcpp::NumericMatrix rcpp_get_sp_dists_paired_par (const Rcpp::DataFrame graph,
         const Rcpp::DataFrame vert_map_in,
         Rcpp::IntegerVector fromi,
@@ -101,6 +107,12 @@ Rcpp::NumericMatrix rcpp_get_sp_dists_categorical (const Rcpp::DataFrame graph,
         const std::string& heap_type,
         const bool proportions_only);
 
+Rcpp::NumericMatrix rcpp_get_sp_dists_categ_paired (const Rcpp::DataFrame graph,
+        const Rcpp::DataFrame vert_map_in,
+        Rcpp::IntegerVector fromi,
+        Rcpp::IntegerVector toi_in,
+        const std::string& heap_type);
+
 Rcpp::NumericMatrix rcpp_get_sp_dists_cat_threshold (const Rcpp::DataFrame graph,
         const Rcpp::DataFrame vert_map_in,
         Rcpp::IntegerVector fromi,
