@@ -205,9 +205,9 @@ test_that ("no geom rownames", {
 
 test_that ("keep cols", {
     hw0 <- weight_streetnet (hampi)
-    expect_equal (ncol (hw0), 15)
+    expect_equal (ncol (hw0), 16)
     hw1 <- weight_streetnet (hampi, keep_cols = "foot")
-    expect_equal (ncol (hw1), 16)
+    expect_equal (ncol (hw1), 17)
     expect_true ("foot" %in% names (hw1))
     expect_false ("foot" %in% names (hw0))
 
@@ -249,12 +249,6 @@ test_that ("graph columns", {
     )
 
     graph <- data.frame (weight_streetnet (hampi)) # rm dodgr_streetnet class
-    graph$d2 <- graph$d
-    expect_error (
-        d <- dodgr_dists (graph, from = from, to = to),
-        "Unable to determine distance column in graph"
-    )
-    graph$d2 <- NULL
     graph$d_wt <- graph$d_weighted
     expect_error (
         d <- dodgr_dists (graph, from = from, to = to),
